[![ci](https://github.com/rvbCMTS/PySkinDose/actions/workflows/ci.yml/badge.svg)](https://github.com/rvbCMTS/PySkinDose/actions/workflows/ci.yml) [![codecov](https://codecov.io/gh/rvbCMTS/PySkinDose/branch/master/graph/badge.svg?token=2O32UO12V6)](https://codecov.io/gh/rvbCMTS/PySkinDose) [![Documentation Status](https://readthedocs.org/projects/pyskindose/badge/?version=latest)](http://pyskindose.readthedocs.io/en/latest/?badge=latest)

# pyskindose

author: Max Hellström

A python program for calculating 3D skin dose maps based on DICOM X-ray Radiation Dose Structured Reports.

Requires Python 3.8 or above. NB! Will soon be upgraded to require Python 3.10 or above.

The documentation is under construction and can be found at [https://pyskindose/readthedocs.io](https://pyskindose.readthedocs.io)

Stay tuned!
